@@ -39,7 +39,7 @@ def FindFunc(dir: str) -> typing.Callable:
     return None
 
 
-def _FuncFromModule(module: types.ModuleType) -> list[typing.Callable]:
+def _FuncFromModule(module: types.ModuleType) -> typing.List[typing.Callable]:
     found = []
     for (name, x) in inspect.getmembers(module, inspect.isfunction):
         if name.startswith("_"):
